.. _trojanvision.datasets:

datasets
=========
.. currentmodule:: trojanvision.datasets

.. toctree::
   :maxdepth: 2

   normal
   folder

.. autofunction:: add_argument
.. autofunction:: create

.. autoclass:: ImageSet
   :members:

.. autoclass:: ImageFolder
   :members:
